@@ -13,9 +13,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
 import os
 from gettext import gettext as _
 
@@ -26,7 +24,7 @@ from gi.repository import Gtk
 
 from pitivi.configure import get_pixmap_dir
 from pitivi.utils.loggable import Loggable
-from pitivi.utils.misc import disconnectAllByFunc
+from pitivi.utils.misc import disconnect_all_by_func
 from pitivi.utils.ui import fix_infobar
 from pitivi.utils.ui import PADDING
 from pitivi.utils.ui import SPACING
@@ -70,11 +68,11 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         self.searchbar.set_orientation(Gtk.Orientation.HORIZONTAL)
         # Prevents being flush against the notebook
         self.searchbar.set_border_width(3)
-        self.searchEntry = Gtk.Entry()
-        self.searchEntry.set_icon_from_icon_name(
+        self.search_entry = Gtk.Entry()
+        self.search_entry.set_icon_from_icon_name(
             Gtk.EntryIconPosition.SECONDARY, "edit-clear-symbolic")
-        self.searchEntry.set_placeholder_text(_("Search..."))
-        self.searchbar.pack_end(self.searchEntry, True, True, 0)
+        self.search_entry.set_placeholder_text(_("Search..."))
+        self.searchbar.pack_end(self.search_entry, True, True, 0)
 
         self.props_widgets = Gtk.Grid()
         self.props_widgets.props.margin = PADDING
@@ -98,7 +96,7 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         self.props_widgets.attach(self.invert_checkbox, 1, 2, 1, 1)
 
         # Set the default values
-        self.__updateBorderScale()
+        self.__update_border_scale()
 
         self.infobar = Gtk.InfoBar()
         fix_infobar(self.infobar)
@@ -107,18 +105,14 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         txtlabel.set_line_wrap(True)
         txtlabel.set_text(
             _("Create a transition by overlapping two adjacent clips on the "
-                "same layer. Click the transition on the timeline to change "
-                "the transition type."))
+              "same layer. Click the transition on the timeline to change "
+              "the transition type."))
         self.infobar.get_content_area().add(txtlabel)
 
         self.storemodel = Gtk.ListStore(GES.Asset, str, str, GdkPixbuf.Pixbuf)
 
         self.iconview_scrollwin = Gtk.ScrolledWindow()
         self.iconview_scrollwin.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
-        # FIXME: the "never" horizontal scroll policy in GTK2 messes up iconview
-        # Re-enable this when we switch to GTK3
-        # See also http://python.6.n6.nabble.com/Cannot-shrink-width-of-scrolled-textview-tp1945060.html
-        # self.iconview_scrollwin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
 
         self.iconview = Gtk.IconView(model=self.storemodel)
         self.iconview.set_pixbuf_column(COL_ICON)
@@ -128,12 +122,12 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         self.iconview_scrollwin.add(self.iconview)
         self.iconview.set_property("has_tooltip", True)
 
-        self.searchEntry.connect("changed", self._searchEntryChangedCb)
-        self.searchEntry.connect("icon-press", self._searchEntryIconClickedCb)
-        self.iconview.connect("query-tooltip", self._queryTooltipCb)
+        self.search_entry.connect("changed", self._search_entry_changed_cb)
+        self.search_entry.connect("icon-press", self._search_entry_icon_press_cb)
+        self.iconview.connect("query-tooltip", self._iconview_query_tooltip_cb)
 
         # Speed-up startup by only checking available transitions on idle
-        GLib.idle_add(self._loadAvailableTransitionsCb)
+        GLib.idle_add(self._load_available_transitions_cb)
 
         self.pack_start(self.infobar, False, False, 0)
         self.pack_start(self.searchbar, False, False, 0)
@@ -141,8 +135,8 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         self.pack_start(self.props_widgets, False, False, 0)
 
         # Create the filterModel for searching
-        self.modelFilter = self.storemodel.filter_new()
-        self.iconview.set_model(self.modelFilter)
+        self.model_filter = self.storemodel.filter_new()
+        self.iconview.set_model(self.model_filter)
 
         self.infobar.show_all()
         self.iconview_scrollwin.show_all()
@@ -167,12 +161,12 @@ class TransitionsListWidget(Gtk.Box, Loggable):
                 self.container_focused = False
                 action_log.commit("Change transaction")
 
-    def __connectUi(self):
-        self.iconview.connect("selection-changed", self._transitionSelectedCb)
-        self.border_scale.connect("value-changed", self._borderScaleCb)
-        self.invert_checkbox.connect("toggled", self._invertCheckboxCb)
-        self.border_mode_normal.connect("released", self._borderTypeChangedCb)
-        self.border_mode_loop.connect("released", self._borderTypeChangedCb)
+    def __connect_ui(self):
+        self.iconview.connect("selection-changed", self._transition_selected_cb)
+        self.border_scale.connect("value-changed", self._border_scale_cb)
+        self.invert_checkbox.connect("toggled", self._invert_checkbox_cb)
+        self.border_mode_normal.connect("released", self._border_type_changed_cb)
+        self.border_mode_loop.connect("released", self._border_type_changed_cb)
         self.element.connect("notify::border", self.__updated_cb)
         self.element.connect("notify::invert", self.__updated_cb)
         self.element.connect("notify::transition-type", self.__updated_cb)
@@ -180,18 +174,18 @@ class TransitionsListWidget(Gtk.Box, Loggable):
     def __updated_cb(self, element, unused_param):
         self._update_ui()
 
-    def __disconnectUi(self):
-        self.iconview.disconnect_by_func(self._transitionSelectedCb)
-        self.border_scale.disconnect_by_func(self._borderScaleCb)
-        self.invert_checkbox.disconnect_by_func(self._invertCheckboxCb)
-        self.border_mode_normal.disconnect_by_func(self._borderTypeChangedCb)
-        self.border_mode_loop.disconnect_by_func(self._borderTypeChangedCb)
-        disconnectAllByFunc(self.element, self.__updated_cb)
+    def __disconnect_ui(self):
+        self.iconview.disconnect_by_func(self._transition_selected_cb)
+        self.border_scale.disconnect_by_func(self._border_scale_cb)
+        self.invert_checkbox.disconnect_by_func(self._invert_checkbox_cb)
+        self.border_mode_normal.disconnect_by_func(self._border_type_changed_cb)
+        self.border_mode_loop.disconnect_by_func(self._border_type_changed_cb)
+        disconnect_all_by_func(self.element, self.__updated_cb)
 
 # UI callbacks
 
-    def _transitionSelectedCb(self, unused_widget):
-        transition_asset = self.getSelectedItem()
+    def _transition_selected_cb(self, unused_widget):
+        transition_asset = self.get_selected_item()
         if not transition_asset:
             # The user clicked between icons
             return False
@@ -205,28 +199,28 @@ class TransitionsListWidget(Gtk.Box, Loggable):
 
         self.element.get_parent().set_asset(transition_asset)
         self.app.write_action("element-set-asset",
-            asset_id=transition_asset.get_id(),
-            element_name=self.element.get_name())
-        self.app.project_manager.current_project.pipeline.flushSeek()
+                              asset_id=transition_asset.get_id(),
+                              element_name=self.element.get_name())
+        self.app.project_manager.current_project.pipeline.flush_seek()
 
         return True
 
-    def _borderScaleCb(self, widget):
+    def _border_scale_cb(self, widget):
         value = widget.get_value()
         self.debug("User changed the border property to %s", value)
         self.element.set_border(int(value))
-        self.app.project_manager.current_project.pipeline.flushSeek()
+        self.app.project_manager.current_project.pipeline.flush_seek()
 
-    def _invertCheckboxCb(self, widget):
+    def _invert_checkbox_cb(self, widget):
         value = widget.get_active()
         self.debug("User changed the invert property to %s", value)
         self.element.set_inverted(value)
-        self.app.project_manager.current_project.pipeline.flushSeek()
+        self.app.project_manager.current_project.pipeline.flush_seek()
 
-    def _borderTypeChangedCb(self, widget):
-        self.__updateBorderScale(widget == self.border_mode_loop)
+    def _border_type_changed_cb(self, widget):
+        self.__update_border_scale(widget == self.border_mode_loop)
 
-    def __updateBorderScale(self, loop=False, border=None):
+    def __update_border_scale(self, loop=False, border=None):
         # The "border" property in gstreamer is unlimited, but if you go over
         # 25 thousand it "loops" the transition instead of smoothing it.
         if border is not None:
@@ -247,18 +241,18 @@ class TransitionsListWidget(Gtk.Box, Loggable):
             self.border_scale.add_mark(
                 25000, Gtk.PositionType.BOTTOM, _("Smooth"))
 
-    def _searchEntryChangedCb(self, unused_entry):
-        self.modelFilter.refilter()
+    def _search_entry_changed_cb(self, entry):
+        self.model_filter.refilter()
 
-    def _searchEntryIconClickedCb(self, entry, unused, unused_1):
+    def _search_entry_icon_press_cb(self, entry, icon_pos, event):
         entry.set_text("")
 
 # UI methods
 
-    def _loadAvailableTransitionsCb(self):
+    def _load_available_transitions_cb(self):
         """Loads the transitions types and icons into the storemodel."""
-        for trans_asset in GES.list_assets(GES.BaseTransitionClip):
-            trans_asset.icon = self._getIcon(trans_asset.get_id())
+        for trans_asset in GES.list_assets(GES.TransitionClip):
+            trans_asset.icon = self._get_icon(trans_asset.get_id())
             self.storemodel.append([trans_asset,
                                     str(trans_asset.get_id()),
                                     str(trans_asset.get_meta(
@@ -266,7 +260,7 @@ class TransitionsListWidget(Gtk.Box, Loggable):
                                     trans_asset.icon])
 
         # Now that the UI is fully ready, enable searching
-        self.modelFilter.set_visible_func(self._setRowVisible, data=None)
+        self.model_filter.set_visible_func(self._set_row_visible_func, data=None)
         # Alphabetical/name sorting instead of based on the ID number
         self.storemodel.set_sort_column_id(
             COL_NAME_TEXT, Gtk.SortType.ASCENDING)
@@ -280,7 +274,7 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         self.iconview.show_all()
         self.props_widgets.show_all()
         self.searchbar.show_all()
-        self.__connectUi()
+        self.__connect_ui()
         # We REALLY want the infobar to be hidden as space is really constrained
         # and yet GTK 3.10 seems to be racy in showing/hiding infobars, so
         # this must happen *after* the tab has been made visible/switched to:
@@ -292,7 +286,7 @@ class TransitionsListWidget(Gtk.Box, Loggable):
             transition_type != GES.VideoStandardTransitionType.CROSSFADE)
         self.__select_transition(transition_type)
         border = self.element.get_border()
-        self.__updateBorderScale(border=border)
+        self.__update_border_scale(border=border)
         self.border_scale.set_value(border)
         self.invert_checkbox.set_active(self.element.is_inverted())
         loop = border >= BORDER_LOOP_THRESHOLD
@@ -313,24 +307,24 @@ class TransitionsListWidget(Gtk.Box, Loggable):
 
     def deactivate(self):
         """Shows the infobar and hides the transitions UI."""
-        self.__disconnectUi()
+        self.__disconnect_ui()
         self.iconview.unselect_all()
         self.iconview.hide()
         self.props_widgets.hide()
         self.searchbar.hide()
         self.infobar.show()
 
-    def _getIcon(self, transition_nick):
+    def _get_icon(self, transition_nick):
         """Gets an icon pixbuf for the specified transition nickname."""
         name = transition_nick + ".png"
         try:
             icon = GdkPixbuf.Pixbuf.new_from_file(
                 os.path.join(self._pixdir, name))
-        except:
+        except GLib.Error:
             icon = self._question_icon
         return icon
 
-    def _queryTooltipCb(self, view, x, y, keyboard_mode, tooltip):
+    def _iconview_query_tooltip_cb(self, view, x, y, keyboard_mode, tooltip):
         is_row, x, y, model, path, iter_ = view.get_tooltip_context(
             x, y, keyboard_mode)
         if not is_row:
@@ -351,14 +345,14 @@ class TransitionsListWidget(Gtk.Box, Loggable):
         tooltip.set_markup(txt)
         return True
 
-    def getSelectedItem(self):
+    def get_selected_item(self):
         path = self.iconview.get_selected_items()
         if path == []:
             return None
-        return self.modelFilter[path[0]][COL_TRANSITION_ASSET]
+        return self.model_filter[path[0]][COL_TRANSITION_ASSET]
 
-    def _setRowVisible(self, model, iter, unused_data):
+    def _set_row_visible_func(self, model, model_iter, data):
         """Filters the icon view to show only the search results."""
-        text = self.searchEntry.get_text().lower()
-        return text in model.get_value(iter, COL_DESC_TEXT).lower() or\
-            text in model.get_value(iter, COL_NAME_TEXT).lower()
+        text = self.search_entry.get_text().lower()
+        return text in model.get_value(model_iter, COL_DESC_TEXT).lower() or\
+            text in model.get_value(model_iter, COL_NAME_TEXT).lower()
