@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Pitivi video editor
 # Copyright (c) 2017, Thibault Saunier <tsaunier@gnome.org>
 #
@@ -12,11 +13,8 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
-# pylint: disable=missing-docstring,invalid-name
-"""GstValidateLauncher testsuite to run out unit tests."""
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
+"""GstValidateLauncher testsuite to run our unit tests."""
 import os
 import sys
 import unittest
@@ -28,21 +26,17 @@ sys.path.insert(0, os.path.join(CDIR, '..'))
 # pylint: disable=wrong-import-position
 # pylint: disable=unused-import
 # Import tests so that the module is initialized
-import tests  # noqa
+import tests
 # pylint: disable=import-error
-from launcher.baseclasses import Test  # noqa
-from launcher.config import GST_VALIDATE_TESTSUITE_VERSION  # noqa
+from launcher.baseclasses import Test
 
 
-# pylint: disable=too-few-public-methods
 class PitiviTest(Test):
-    """A launcher.Test subclass for our unit tests."""
+    """A Test corresponding to a module in our unit tests suite."""
+
     def build_arguments(self):
         """Builds subprocess arguments."""
-        if GST_VALIDATE_TESTSUITE_VERSION == "1.12":
-            self.add_arguments('-m', 'unittest', self.classname)
-        else:
-            self.add_arguments('-m', 'unittest', '.'.join(self.classname.split('.')[1:]))
+        self.add_arguments('-m', 'unittest', '.'.join(self.classname.split('.')[1:]))
 
 
 def setup_tests(test_manager, options):
