@@ -13,9 +13,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
 """Tests for the timeline.previewers module."""
 # pylint: disable=protected-access
 import os
@@ -27,21 +25,22 @@ from gi.repository import GdkPixbuf
 from gi.repository import GES
 from gi.repository import Gst
 
+from pitivi.timeline.previewers import delete_all_files_in_dir
 from pitivi.timeline.previewers import get_wavefile_location_for_uri
+from pitivi.timeline.previewers import Previewer
 from pitivi.timeline.previewers import THUMB_HEIGHT
 from pitivi.timeline.previewers import THUMB_PERIOD
 from pitivi.timeline.previewers import ThumbnailCache
-from pitivi.timeline.previewers import VideoPreviewer
 from tests import common
-from tests.test_media_library import BaseTestMediaLibrary
+from tests.test_medialibrary import BaseTestMediaLibrary
 
 
 SIMPSON_WAVFORM_VALUES = [
-    0.10277689599093834, 0.50788916706114862, 0.91300143813135892, 1.3181137092015693,
-    1.7232259802717795, 2.1283382513419897, 2.5334505224121999, 2.9385627934824101,
-    3.3436750645526203, 3.7487873356228305, 3.748787335622831, 3.6974645491239455,
-    3.6461417626250601, 3.5948189761261746, 3.5434961896272892, 3.4921734031284037,
-    3.4408506166295183, 3.3895278301306329, 3.3382050436317474, 3.286882257132862,
+    0.10277689604421922, 0.5078891671078481, 0.913001438171477, 1.318113709235106,
+    1.7232259802987349, 2.1283382513623637, 2.5334505224259924, 2.9385627934896212,
+    3.34367506455325, 3.748787335616879, 3.7487873356168793, 3.697464549118655,
+    3.646141762620431, 3.5948189761222067, 3.5434961896239825, 3.4921734031257583,
+    3.440850616627534, 3.38952783012931, 3.3382050436310857, 3.2868822571328615,
     3.2868822571328606, 3.4364524655420996, 3.5860226739513386, 3.7355928823605775,
     3.8851630907698165, 4.034733299179055, 4.1843035075882939, 4.3338737159975329,
     4.4834439244067719, 4.6330141328160108, 4.6330141328160108, 4.6166031969548991,
@@ -98,22 +97,16 @@ class TestAudioPreviewer(BaseTestMediaLibrary):
         self.assertEqual(samples, SIMPSON_WAVFORM_VALUES)
 
 
-class TestVideoPreviewer(common.TestCase):
-    """Tests for the `VideoPreviewer` class."""
+class TestPreviewer(common.TestCase):
+    """Tests for the `Previewer` class."""
 
     def test_thumb_interval(self):
-        """Checks the `thumb_interval` property."""
-        ges_elem = mock.Mock()
-        ges_elem.props.uri = common.get_sample_uri("1sec_simpsons_trailer.mp4")
-        ges_elem.props.id = common.get_sample_uri("1sec_simpsons_trailer.mp4")
-        previewer = VideoPreviewer(ges_elem, 94)
-        previewer.thumb_width = 1  # Just so it's not None.
-
+        """Checks the `thumb_interval` method."""
         def run_thumb_interval(interval):
             """Runs thumb_interval."""
-            with mock.patch("pitivi.utils.timeline.Zoomable.pixelToNs") as pixel_to_ns:
+            with mock.patch("pitivi.utils.timeline.Zoomable.pixel_to_ns") as pixel_to_ns:
                 pixel_to_ns.return_value = interval
-                return previewer.thumb_interval
+                return Previewer.thumb_interval(1)
 
         self.assertEqual(run_thumb_interval(1), THUMB_PERIOD)
         self.assertEqual(run_thumb_interval(THUMB_PERIOD - 1), THUMB_PERIOD)
@@ -178,3 +171,19 @@ class TestThumbnailCache(BaseTestMediaLibrary):
                 thumb_cache = ThumbnailCache(sample_uri)
                 self.assertTrue(Gst.SECOND in thumb_cache)
                 self.assertIsNotNone(thumb_cache[Gst.SECOND])
+
+
+class TestFunctions(BaseTestMediaLibrary):
+    """Tests for the standalone functions."""
+
+    def test_delete_all_files_in_dir(self):
+        """Checks whether files in sub directories are deleted."""
+        with tempfile.TemporaryDirectory() as dir_a, \
+                tempfile.NamedTemporaryFile(dir=dir_a, delete=False), \
+                tempfile.TemporaryDirectory(dir=dir_a) as dir_a_b, \
+                tempfile.NamedTemporaryFile(dir=dir_a_b) as file_a_b1:
+            self.assertEqual(len(os.listdir(dir_a)), 2)
+            self.assertEqual(len(os.listdir(dir_a_b)), 1)
+            delete_all_files_in_dir(dir_a)
+            self.assertEqual(os.listdir(dir_a), [os.path.basename(dir_a_b)])
+            self.assertEqual(os.listdir(dir_a_b), [os.path.basename(file_a_b1.name)])
