@@ -14,9 +14,9 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
+"""Tests for the pitivi.project module."""
+# pylint: disable=protected-access
 import collections
 import os
 import tempfile
@@ -26,7 +26,8 @@ from unittest import mock
 from gi.repository import GES
 from gi.repository import Gst
 
-from pitivi import medialibrary
+from pitivi.medialibrary import AssetThumbnail
+from pitivi.medialibrary import MediaLibraryWidget
 from pitivi.project import Project
 from pitivi.project import ProjectManager
 from pitivi.utils.misc import path_from_uri
@@ -34,23 +35,23 @@ from pitivi.utils.proxy import ProxyingStrategy
 from tests import common
 
 
-class ProjectManagerListener(object):
+class ProjectManagerListener():
 
     def __init__(self, manager):
         self.manager = manager
-        self.connectToProjectManager(self.manager)
+        self.connect_to_project_manager()
         self._reset()
 
     def _reset(self):
         self.signals = []
 
-    def connectToProjectManager(self, manager):
+    def connect_to_project_manager(self):
         for signal in ("new-project-loading", "new-project-loaded",
                        "new-project-created", "new-project-failed", "missing-uri",
                        "closing-project", "project-closed"):
-            self.manager.connect(signal, self._recordSignal, signal)
+            self.manager.connect(signal, self._record_signal, signal)
 
-    def _recordSignal(self, *args):
+    def _record_signal(self, *args):
         signal = args[-1]
         args = args[1:-1]
         self.signals.append((signal, args))
@@ -62,83 +63,61 @@ class TestProjectManager(common.TestCase):
 
     def setUp(self):
         super(TestProjectManager, self).setUp()
-        self.setupApp()
+        self.setup_app()
 
-    def setupApp(self, app=None):
+    def setup_app(self, app=None):
         if not app:
             app = mock.MagicMock()
         self.manager = ProjectManager(app)
         self.listener = ProjectManagerListener(self.manager)
         self.signals = self.listener.signals
 
-    def testLoadProjectFailedUnknownFormat(self):
-        """
-        Check that new-project-failed is emitted when we don't have a suitable
-        formatter.
-        """
-        uri = "file:///Untitled.meh"
-        self.manager.loadProject(uri)
+    def test_loading_missing_project_file(self):
+        """Checks new-project-failed is emitted for unsuitable formatters."""
+        project_uri = Gst.filename_to_uri(tempfile.NamedTemporaryFile().name)
+        self.manager.load_project(project_uri)
 
         # loading
         name, args = self.signals[0]
-        self.assertEqual(uri, args[0].get_uri(), self.signals)
+        self.assertEqual(project_uri, args[0].get_uri(), self.signals)
 
         # failed
         name, args = self.signals[1]
         self.assertEqual("new-project-failed", name)
-        signalUri, unused_message = args
-        self.assertEqual(uri, signalUri, self.signals)
+        signal_uri, unused_message = args
+        self.assertEqual(project_uri, signal_uri, self.signals)
 
-    def testLoadProjectClosesCurrent(self):
-        """
-        Check that new-project-failed is emitted if we can't close the current
-        project instance.
-        """
-        state = {"tried-close": False}
+    def test_new_blank_project_signals(self):
+        self.manager.new_blank_project()
 
-        def close():
-            state["tried-close"] = True
-            return False
-        self.manager.closeRunningProject = close
-
-        uri = "file:///Untitled.xptv"
-        self.manager.current_project = mock.Mock()
-        self.manager.loadProject(uri)
-
-        self.assertEqual(0, len(self.signals))
-        self.assertTrue(state["tried-close"], self.signals)
-
-    def testLoadProject(self):
-        self.manager.newBlankProject()
-
-        name, args = self.signals[0]
+        name, _args = self.signals[0]
         self.assertEqual("new-project-loading", name, self.signals)
 
-        name, args = self.signals[1]
+        name, _args = self.signals[1]
         self.assertEqual("new-project-created", name, self.signals)
 
-        name, args = self.signals[2]
+        name, _args = self.signals[2]
         self.assertEqual("new-project-loaded", name, self.signals)
 
-    def testMissingUriForwarded(self):
-        self.setupApp(app=common.create_pitivi_mock())
+    def test_missing_uri_forwarded(self):
+        self.setup_app(app=common.create_pitivi_mock())
         mainloop = common.create_main_loop()
 
-        def missingUriCb(self, project, error, clip_asset, result):
+        def missing_uri_cb(self, project, error, clip_asset, result):
             result[0] = True
             mainloop.quit()
 
         result = [False]
-        self.manager.connect("missing-uri", missingUriCb, result)
+        self.manager.connect("missing-uri", missing_uri_cb, result)
 
         with common.cloned_sample():
             asset_uri = common.get_sample_uri("missing.png")
             with common.created_project_file(asset_uri) as uri:
-                self.assertTrue(self.manager.loadProject(uri))
+                self.assertIsNotNone(self.manager.load_project(uri))
                 mainloop.run()
         self.assertTrue(result[0], "missing-uri has not been emitted")
 
-    def testLoaded(self):
+    def test_loaded(self):
         mainloop = common.create_main_loop()
 
         def new_project_loaded_cb(project_manager, project):
@@ -149,66 +128,50 @@ class TestProjectManager(common.TestCase):
         with common.cloned_sample("flat_colour1_640x480.png"):
             asset_uri = common.get_sample_uri("flat_colour1_640x480.png")
             with common.created_project_file(asset_uri=asset_uri) as uri:
-                self.assertTrue(self.manager.loadProject(uri))
+                project = self.manager.load_project(uri)
+                self.assertIsNotNone(project)
                 mainloop.run()
 
-        project = self.manager.current_project
         self.assertFalse(project.at_least_one_asset_missing)
         self.assertTrue(project.loaded)
-        self.assertFalse(project.hasUnsavedModifications())
+        self.assertFalse(project.has_unsaved_modifications())
 
-    def testCloseRunningProjectNoProject(self):
-        self.assertTrue(self.manager.closeRunningProject())
+    def test_close_running_project_no_project(self):
+        self.assertTrue(self.manager.close_running_project())
         self.assertFalse(self.signals)
 
-    def testCloseRunningProjectRefuseFromSignal(self):
-        def closing(manager, project):
+    def test_close_running_project_refuse_from_signal(self):
+        def closing_cb(manager, project):
             return False
 
         self.manager.current_project = mock.Mock()
         self.manager.current_project.uri = "file:///ciao"
-        self.manager.connect("closing-project", closing)
+        self.manager.connect("closing-project", closing_cb)
 
-        self.assertFalse(self.manager.closeRunningProject())
+        self.assertFalse(self.manager.close_running_project())
         self.assertEqual(1, len(self.signals))
         name, args = self.signals[0]
         self.assertEqual("closing-project", name)
         project = args[0]
         self.assertTrue(project is self.manager.current_project)
 
-    def testCloseRunningProject(self):
-        current = mock.Mock()
-        current.uri = None
-        self.manager.current_project = current
-        self.assertTrue(self.manager.closeRunningProject())
-        self.assertEqual(2, len(self.signals))
+    def test_close_running_project(self):
+        project = self.manager.new_blank_project()
+        self.assertTrue(self.manager.close_running_project())
+        self.assertEqual(5, len(self.signals), self.signals)
 
-        name, args = self.signals[0]
+        name, args = self.signals[-2]
         self.assertEqual("closing-project", name)
-        project = args[0]
-        self.assertTrue(project is current)
+        self.assertEqual(args[0], project)
 
-        name, args = self.signals[1]
+        name, args = self.signals[-1]
         self.assertEqual("project-closed", name)
-        project = args[0]
-        self.assertTrue(project is current)
+        self.assertEqual(args[0], project)
 
         self.assertTrue(self.manager.current_project is None)
 
-    def testNewBlankProjectCantCloseCurrent(self):
-        def closing(manager, project):
-            return False
-
-        self.manager.current_project = mock.Mock()
-        self.manager.current_project.uri = "file:///ciao"
-        self.manager.connect("closing-project", closing)
-        self.assertFalse(self.manager.newBlankProject())
-        self.assertEqual(1, len(self.signals))
-        signal, args = self.signals[0]
-        self.assertEqual("closing-project", signal)
-
-    def testNewBlankProject(self):
-        self.assertTrue(self.manager.newBlankProject())
+    def test_new_blank_project(self):
+        self.assertIsNotNone(self.manager.new_blank_project())
         self.assertEqual(3, len(self.signals))
 
         name, args = self.signals[0]
@@ -226,8 +189,14 @@ class TestProjectManager(common.TestCase):
         project = args[0]
         self.assertTrue(project is self.manager.current_project)
 
-    def testSaveProject(self):
-        self.assertTrue(self.manager.newBlankProject())
+    def test_marker_container(self):
+        project = self.manager.new_blank_project()
+        self.assertIsNotNone(project)
+        self.assertIsNotNone(project.ges_timeline)
+        self.assertIsNotNone(project.ges_timeline.get_marker_list("markers"))
+
+    def test_save_project(self):
+        self.manager.new_blank_project()
 
         unused, path = tempfile.mkstemp(suffix=".xges")
         unused, path2 = tempfile.mkstemp(suffix=".xges")
@@ -236,14 +205,14 @@ class TestProjectManager(common.TestCase):
             uri2 = "file://" + os.path.abspath(path2)
 
             # Save the project.
-            self.assertTrue(self.manager.saveProject(uri=uri, backup=False))
+            self.assertTrue(self.manager.save_project(uri=uri, backup=False))
             self.assertTrue(os.path.isfile(path))
 
             # Wait a bit.
             time.sleep(0.1)
 
             # Save the project at a new location.
-            self.assertTrue(self.manager.saveProject(uri2, backup=False))
+            self.assertTrue(self.manager.save_project(uri2, backup=False))
             self.assertTrue(os.path.isfile(path2))
 
             # Make sure the old path and the new path have different mtimes.
@@ -255,7 +224,7 @@ class TestProjectManager(common.TestCase):
             time.sleep(0.1)
 
             # Save project again under the new path (by omitting uri arg)
-            self.assertTrue(self.manager.saveProject(backup=False))
+            self.assertTrue(self.manager.save_project(backup=False))
 
             # regression test for bug 594396
             # make sure we didn't save to the old URI
@@ -266,26 +235,26 @@ class TestProjectManager(common.TestCase):
             os.remove(path)
             os.remove(path2)
 
-    def testMakeBackupUri(self):
+    def test_make_backup_uri(self):
         uri = "file:///tmp/x.xges"
-        self.assertEqual(uri + "~", self.manager._makeBackupURI(uri))
+        self.assertEqual(uri + "~", self.manager._make_backup_uri(uri))
 
-    def testBackupProject(self):
-        self.manager.newBlankProject()
+    def test_backup_project(self):
+        self.manager.new_blank_project()
 
         # Assign an uri to the project where it's saved by default.
         unused, xges_path = tempfile.mkstemp(suffix=".xges")
         uri = "file://" + os.path.abspath(xges_path)
         self.manager.current_project.uri = uri
         # This is where the automatic backup file is saved.
-        backup_uri = self.manager._makeBackupURI(uri)
+        backup_uri = self.manager._make_backup_uri(uri)
 
         # Save the backup
-        self.assertTrue(self.manager.saveProject(
+        self.assertTrue(self.manager.save_project(
             self.manager.current_project, backup=True))
         self.assertTrue(os.path.isfile(path_from_uri(backup_uri)))
 
-        self.manager.closeRunningProject()
+        self.manager.close_running_project()
         self.assertFalse(os.path.isfile(path_from_uri(backup_uri)),
                          "Backup file not deleted when project closed")
 
@@ -295,13 +264,13 @@ class TestProjectLoading(common.TestCase):
     def test_loaded_callback(self):
         mainloop = common.create_main_loop()
 
-        def loaded(project, timeline):
+        def loaded_cb(project, timeline):
             # If not called, the timeout of the mainloop will fail the test.
             mainloop.quit()
 
         # Create a blank project and save it.
         project = common.create_project()
-        project.connect("loaded", loaded)
+        project.connect("loaded", loaded_cb)
         mainloop.run()
         # The blank project loading succeeded emitting signal "loaded".
 
@@ -316,7 +285,7 @@ class TestProjectLoading(common.TestCase):
             project.save(project.ges_timeline, uri, None, overwrite=True)
 
             project2 = common.create_project()
-            project2.connect("loaded", loaded)
+            project2.connect("loaded", loaded_cb)
             mainloop.run()
             # The blank project loading succeeded emitting signal "loaded".
 
@@ -327,9 +296,7 @@ class TestProjectLoading(common.TestCase):
 
     def test_asset_added_signal(self):
         app = common.create_pitivi()
-        self.assertTrue(app.project_manager.newBlankProject())
-
-        project = app.project_manager.current_project
+        project = app.project_manager.new_blank_project()
         proxy_manager = app.proxy_manager
 
         mainloop = common.create_main_loop()
@@ -346,32 +313,22 @@ class TestProjectLoading(common.TestCase):
         proxy_manager.connect("proxy-ready", proxy_ready_cb)
 
         uris = [common.get_sample_uri("tears_of_steel.webm")]
-        project.addUris(uris)
+        project.add_uris(uris)
 
         mainloop.run()
 
         self.assertEqual(len(assets), 1, assets)
 
-    def create_project_file_from_xges(self, app, xges):
-        unused, xges_path = tempfile.mkstemp(suffix=".xges")
-        proj_uri = Gst.filename_to_uri(os.path.abspath(xges_path))
-        app.project_manager.saveProject(uri=proj_uri)
-
-        with open(xges_path, "w") as f:
-            f.write(xges)
-
-        return proj_uri
-
     def load_project_with_missing_proxy(self):
         """Loads a project with missing proxies."""
         uris = [common.get_sample_uri("1sec_simpsons_trailer.mp4")]
-        proxy_uri = uris[0] + ".232417.proxy.mkv"
-        PROJECT_STR = """<ges version='0.3'>
+        proxy_uri = uris[0] + ".232417.proxy.mov"
+        xges = r"""<ges version='0.3'>
   <project properties='properties;' metadatas='metadatas, name=(string)&quot;New\ Project&quot;, author=(string)Unknown, render-scale=(double)100;'>
     <encoding-profiles>
     </encoding-profiles>
     <ressources>
-      <asset id='%(uri)s' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228000000;' metadatas='metadatas, audio-codec=(string)&quot;MPEG-4\ AAC\ audio&quot;, maximum-bitrate=(uint)130625, bitrate=(uint)130625, datetime=(datetime)2007-02-19T05:03:04Z, encoder=(string)Lavf54.6.100, container-format=(string)&quot;ISO\ MP4/M4A&quot;, video-codec=(string)&quot;H.264\ /\ AVC&quot;, file-size=(guint64)232417;'  proxy-id='file:///home/thiblahute/devel/pitivi/flatpak/pitivi/tests/samples/1sec_simpsons_trailer.mp4.232417.proxy.mkv' />
+      <asset id='%(uri)s' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228000000;' metadatas='metadatas, audio-codec=(string)&quot;MPEG-4\ AAC\ audio&quot;, maximum-bitrate=(uint)130625, bitrate=(uint)130625, datetime=(datetime)2007-02-19T05:03:04Z, encoder=(string)Lavf54.6.100, container-format=(string)&quot;ISO\ MP4/M4A&quot;, video-codec=(string)&quot;H.264\ /\ AVC&quot;, file-size=(guint64)232417;'  proxy-id='file:///home/thiblahute/devel/pitivi/flatpak/pitivi/tests/samples/1sec_simpsons_trailer.mp4.232417.proxy.mov' />
       <asset id='%(proxy_uri)s' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228020833;' metadatas='metadatas, container-format=(string)Matroska, audio-codec=(string)Opus, language-code=(string)en, encoder=(string)Lavf54.6.100, bitrate=(uint)64000, video-codec=(string)&quot;Motion\ JPEG&quot;, file-size=(guint64)4695434;' />
     </ressources>
     <timeline properties='properties, auto-transition=(boolean)true, snapping-distance=(guint64)0;' metadatas='metadatas, duration=(guint64)0;'>
@@ -392,14 +349,15 @@ class TestProjectLoading(common.TestCase):
     </timeline>
 </project>
 </ges>""" % {"uri": uris[0], "proxy_uri": proxy_uri}
-        app = common.create_pitivi(proxyingStrategy=ProxyingStrategy.ALL)
+        app = common.create_pitivi(proxying_strategy=ProxyingStrategy.ALL)
+        app.recent_manager.remove_item = mock.Mock(return_value=True)
         proxy_manager = app.proxy_manager
         project_manager = app.project_manager
-        medialib = medialibrary.MediaLibraryWidget(app)
+        medialib = MediaLibraryWidget(app)
 
         mainloop = common.create_main_loop()
 
-        proj_uri = self.create_project_file_from_xges(app, PROJECT_STR)
+        proj_uri = self.create_project_file_from_xges(xges)
 
         def closing_project_cb(*args, **kwargs):
             # Do not ask whether to save project on closing.
@@ -412,20 +370,20 @@ class TestProjectLoading(common.TestCase):
         project_manager.connect("closing-project", closing_project_cb)
         proxy_manager.connect_after("proxy-ready", proxy_ready_cb)
 
-        app.project_manager.loadProject(proj_uri)
+        app.project_manager.load_project(proj_uri)
         return mainloop, app, medialib, proxy_uri
 
     def test_load_project_with_missing_proxy(self):
         """Checks loading a project with missing proxies."""
         with common.cloned_sample("1sec_simpsons_trailer.mp4"):
-            mainloop, app, medialib, proxy_uri = self.load_project_with_missing_proxy()
+            mainloop, _app, medialib, proxy_uri = self.load_project_with_missing_proxy()
             mainloop.run()
 
-        self.assertEqual(len(medialib.storemodel), 1)
-        self.assertEqual(medialib.storemodel[0][medialibrary.COL_ASSET].props.id,
+        self.assertEqual(medialib.store.get_n_items(), 1)
+        self.assertEqual(medialib.store[0].asset.props.id,
                          proxy_uri)
-        self.assertEqual(medialib.storemodel[0][medialibrary.COL_THUMB_DECORATOR].state,
-                         medialibrary.AssetThumbnail.PROXIED)
+        self.assertEqual(medialib.store[0].thumb_decorator.state,
+                         AssetThumbnail.PROXIED)
 
     def test_load_project_with_missing_proxy_progress_tracking(self):
         """Checks progress tracking of loading project with missing proxies."""
@@ -436,17 +394,17 @@ class TestProjectLoading(common.TestCase):
             # This way we are sure it will not finish before we test
             # the state while it is being rebuilt.
             with mock.patch.object(GstTranscoder.Transcoder, "run_async"):
-                mainloop, app, medialib, proxy_uri = self.load_project_with_missing_proxy()
+                mainloop, app, medialib, _proxy_uri = self.load_project_with_missing_proxy()
                 uri = common.get_sample_uri("1sec_simpsons_trailer.mp4")
 
                 app.project_manager.connect("new-project-loaded", lambda x, y: mainloop.quit())
                 mainloop.run()
 
-        self.assertEqual(len(medialib.storemodel), 1)
-        self.assertEqual(medialib.storemodel[0][medialibrary.COL_ASSET].props.id,
+        self.assertEqual(medialib.store.get_n_items(), 1)
+        self.assertEqual(medialib.store[0].asset.props.id,
                          uri)
-        self.assertEqual(medialib.storemodel[0][medialibrary.COL_THUMB_DECORATOR].state,
-                         medialibrary.AssetThumbnail.IN_PROGRESS)
+        self.assertEqual(medialib.store[0].thumb_decorator.state,
+                         AssetThumbnail.IN_PROGRESS)
 
     def test_load_project_with_missing_proxy_stop_generating_and_proxy(self):
         """Checks cancelling creation of a missing proxies and forcing it again."""
@@ -461,36 +419,36 @@ class TestProjectLoading(common.TestCase):
 
                 app.project_manager.connect("new-project-loaded", lambda x, y: mainloop.quit())
                 mainloop.run()
-                asset = medialib.storemodel[0][medialibrary.COL_ASSET]
+                asset = medialib.store[0].asset
                 app.project_manager.current_project.disable_proxies_for_assets([asset])
 
-            row, = medialib.storemodel
-            asset = row[medialibrary.COL_ASSET]
+            row = medialib.store[0]
+            asset = row.asset
             self.assertEqual(medialib._progressbar.get_fraction(), 1.0)
             uri = common.get_sample_uri("1sec_simpsons_trailer.mp4")
             self.assertEqual(asset.props.id, uri)
             self.assertEqual(asset.ready, True)
             self.assertEqual(asset.creation_progress, 100)
-            self.assertEqual(row[medialibrary.COL_THUMB_DECORATOR].state,
-                             medialibrary.AssetThumbnail.NO_PROXY)
+            self.assertEqual(row.thumb_decorator.state,
+                             AssetThumbnail.NO_PROXY)
 
             app.project_manager.current_project.use_proxies_for_assets([asset])
             mainloop.run()
 
-        row, = medialib.storemodel
-        asset = row[medialibrary.COL_ASSET]
+        row = medialib.store[0]
+        asset = row.asset
         self.assertEqual(medialib._progressbar.is_visible(), False)
         self.assertEqual(asset.props.id, proxy_uri)
         self.assertEqual(asset.ready, True)
         self.assertEqual(asset.creation_progress, 100)
-        self.assertEqual(row[medialibrary.COL_THUMB_DECORATOR].state,
-                         medialibrary.AssetThumbnail.PROXIED)
+        self.assertEqual(row.thumb_decorator.state,
+                         AssetThumbnail.PROXIED)
 
     def test_loading_project_with_moved_asset(self):
         """Loads a project with moved asset."""
-        app = common.create_pitivi(proxyingStrategy=ProxyingStrategy.NOTHING)
+        app = common.create_pitivi(proxying_strategy=ProxyingStrategy.NOTHING)
 
-        proj_uri = self.create_project_file_from_xges(app, """<ges version='0.3'>
+        proj_uri = self.create_project_file_from_xges("""<ges version='0.3'>
             <project properties='properties;' metadatas='metadatas;'>
                 <ressources>
                     <asset id='file://this/is/a/moved/asset.mp4' extractable-type-name='GESUriClip'
@@ -499,7 +457,7 @@ class TestProjectLoading(common.TestCase):
             </project>
             </ges>""")
         project_manager = app.project_manager
-        medialib = medialibrary.MediaLibraryWidget(app)
+        medialib = MediaLibraryWidget(app)
 
         mainloop = common.create_main_loop()
 
@@ -512,34 +470,37 @@ class TestProjectLoading(common.TestCase):
         project_manager.connect("missing-uri", missing_uri_cb)
         project_manager.connect("new-project-loaded", new_project_loaded_cb)
 
-        project_manager.loadProject(proj_uri)
+        project_manager.load_project(proj_uri)
         with common.cloned_sample("1sec_simpsons_trailer.mp4"):
             mainloop.run()
         self.assertEqual(medialib._progressbar.get_fraction(), 1.0)
 
     def test_loading_project_with_moved_assets_and_deleted_proxy(self):
-        """Loads a project with moved asset as deleted proxy file."""
-
+        """Loads a project with moved asset and deleted proxy file."""
         mainloop = common.create_main_loop()
 
-        def proxy_ready_cb(unused_proxy_manager, asset, proxy):
-            mainloop.quit()
+        created_proxies = []
 
-        app = common.create_pitivi(proxyingStrategy=ProxyingStrategy.ALL)
+        def proxy_ready_cb(unused_proxy_manager, asset, proxy):
+            created_proxies.append(asset)
+            if len(created_proxies) == 2:
+                mainloop.quit()
+
+        app = common.create_pitivi(proxying_strategy=ProxyingStrategy.ALL)
         app.proxy_manager.connect("proxy-ready", proxy_ready_cb)
 
-        proj_uri = self.create_project_file_from_xges(app, """<ges version='0.3'>
+        proj_uri = self.create_project_file_from_xges(r"""<ges version='0.3'>
   <project properties='properties;' metadatas='metadatas, name=(string)&quot;New\ Project&quot;, author=(string)Unknown, render-scale=(double)100, format-version=(string)0.3;'>
     <ressources>
-      <asset id='file:///nop/1sec_simpsons_trailer.mp4' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228000000;' metadatas='metadatas, audio-codec=(string)&quot;MPEG-4\ AAC\ audio&quot;, maximum-bitrate=(uint)130625, bitrate=(uint)130625, datetime=(datetime)2007-02-19T05:03:04Z, encoder=(string)Lavf54.6.100, container-format=(string)&quot;ISO\ MP4/M4A&quot;, video-codec=(string)&quot;H.264\ /\ AVC&quot;, file-size=(guint64)232417;'  proxy-id='file:///nop/1sec_simpsons_trailer.mp4.232417.proxy.mkv' />
-      <asset id='file:///nop/tears_of_steel.webm' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)2003000000;' metadatas='metadatas, container-format=(string)Matroska, language-code=(string)und, application-name=(string)Lavc56.60.100, encoder=(string)&quot;Xiph.Org\ libVorbis\ I\ 20150105\ \(\342\233\204\342\233\204\342\233\204\342\233\204\)&quot;, encoder-version=(uint)0, audio-codec=(string)Vorbis, nominal-bitrate=(uint)80000, bitrate=(uint)80000, video-codec=(string)&quot;VP8\ video&quot;, file-size=(guint64)223340;' />
-      <asset id='file:///nop/1sec_simpsons_trailer.mp4.232417.proxy.mkv' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228020833;' metadatas='metadatas, container-format=(string)Matroska, audio-codec=(string)Opus, language-code=(string)en, encoder=(string)Lavf54.6.100, bitrate=(uint)64000, video-codec=(string)&quot;Motion\ JPEG&quot;, file-size=(guint64)4694708;' />
-      <asset id='file:///nop/tears_of_steel.webm.223340.proxy.mkv' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)2003000000;' metadatas='metadatas, container-format=(string)Matroska, language-code=(string)und, application-name=(string)Lavc56.60.100, encoder=(string)&quot;Xiph.Org\ libVorbis\ I\ 20150105\ \(\342\233\204\342\233\204\342\233\204\342\233\204\)&quot;, encoder-version=(uint)0, audio-codec=(string)Vorbis, nominal-bitrate=(uint)80000, bitrate=(uint)80000, video-codec=(string)&quot;VP8\ video&quot;, file-size=(guint64)223340;' />
+      <asset id='file:///nop/1sec_simpsons_trailer.mp4' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228000000;' metadatas='metadatas, audio-codec=(string)&quot;MPEG-4\ AAC\ audio&quot;, maximum-bitrate=(uint)130625, bitrate=(uint)130625, datetime=(datetime)2007-02-19T05:03:04Z, encoder=(string)Lavf54.6.100, container-format=(string)&quot;ISO\ MP4/M4A&quot;, video-codec=(string)&quot;H.264\ /\ AVC&quot;, file-size=(guint64)232417;'  proxy-id='file:///nop/1sec_simpsons_trailer.mp4.232417.proxy.mov' />
+      <asset id='file:///nop/tears_of_steel.webm' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)2003000000;' metadatas='metadatas, container-format=(string)Matroska, language-code=(string)und, application-name=(string)Lavc56.60.100, encoder=(string)&quot;Xiph.Org\ libVorbis\ I\ 20150105\ \(\342\233\204\342\233\204\342\233\204\342\233\204\)&quot;, encoder-version=(uint)0, audio-codec=(string)Vorbis, nominal-bitrate=(uint)80000, bitrate=(uint)80000, video-codec=(string)&quot;VP8\ video&quot;, file-size=(guint64)223340;' proxy-id='file:///nop/tears_of_steel.webm.223340.proxy.mov'/>
+      <asset id='file:///nop/1sec_simpsons_trailer.mp4.232417.proxy.mov' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)1228020833;' metadatas='metadatas, container-format=(string)Matroska, audio-codec=(string)Opus, language-code=(string)en, encoder=(string)Lavf54.6.100, bitrate=(uint)64000, video-codec=(string)&quot;Motion\ JPEG&quot;, file-size=(guint64)4694708;' />
+      <asset id='file:///nop/tears_of_steel.webm.223340.proxy.mov' extractable-type-name='GESUriClip' properties='properties, supported-formats=(int)6, duration=(guint64)2003000000;' metadatas='metadatas, container-format=(string)Matroska, language-code=(string)und, application-name=(string)Lavc56.60.100, encoder=(string)&quot;Xiph.Org\ libVorbis\ I\ 20150105\ \(\342\233\204\342\233\204\342\233\204\342\233\204\)&quot;, encoder-version=(uint)0, audio-codec=(string)Vorbis, nominal-bitrate=(uint)80000, bitrate=(uint)80000, video-codec=(string)&quot;VP8\ video&quot;, file-size=(guint64)223340;' />
     </ressources>
 </project>
 </ges>""")
         project_manager = app.project_manager
-        medialib = medialibrary.MediaLibraryWidget(app)
+        medialib = MediaLibraryWidget(app)
 
         # Remove proxy
         with common.cloned_sample("1sec_simpsons_trailer.mp4", "tears_of_steel.webm"):
@@ -555,30 +516,29 @@ class TestProjectLoading(common.TestCase):
             project_manager.connect("missing-uri", missing_uri_cb)
             project_manager.connect("new-project-loaded", new_project_loaded_cb)
 
-            project_manager.loadProject(proj_uri)
+            project_manager.load_project(proj_uri)
             mainloop.run()
             self.assertEqual(len(missing_uris), 1,
-                "missing_uri_cb should be called only once, got %s." % missing_uris)
+                             "missing_uri_cb should be called only once, got %s." % missing_uris)
             self.assertEqual(medialib._progressbar.get_fraction(), 1.0)
             mainloop.run()
-            self.assertEqual(len(medialib.storemodel), 2,
-                "We should have one asset displayed in the MediaLibrary.")
-            self.assertEqual(medialib.storemodel[0][medialibrary.COL_THUMB_DECORATOR].state,
-                             medialibrary.AssetThumbnail.PROXIED)
-            self.assertEqual(medialib.storemodel[1][medialibrary.COL_THUMB_DECORATOR].state,
-                             medialibrary.AssetThumbnail.IN_PROGRESS)
+            self.assertEqual(medialib.store.get_n_items(), 2,
+                             "We should have one asset displayed in the MediaLibrary.")
+
+            self.assertEqual(medialib.store[0].thumb_decorator.state, AssetThumbnail.PROXIED)
+            self.assertEqual(medialib.store[1].thumb_decorator.state, AssetThumbnail.PROXIED)
 
 
 class TestProjectSettings(common.TestCase):
 
-    def testAudio(self):
+    def test_audio(self):
         project = common.create_project()
         project.audiochannels = 2
         self.assertEqual(2, project.audiochannels)
         project.audiorate = 44100
         self.assertEqual(44100, project.audiorate)
 
-    def testVideo(self):
+    def test_video(self):
         project = common.create_project()
         project.videowidth = 1920
         self.assertEqual(1920, project.videowidth)
@@ -587,12 +547,12 @@ class TestProjectSettings(common.TestCase):
         project.videorate = Gst.Fraction(50, 7)
         self.assertEqual(Gst.Fraction(50, 7), project.videorate)
 
-    def testSetAudioProp(self):
+    def test_set_audio_prop(self):
         timeline = common.create_timeline_container()
         project = timeline.app.project_manager.current_project
-        project.addUris([common.get_sample_uri("mp3_sample.mp3")])
+        project.add_uris([common.get_sample_uri("mp3_sample.mp3")])
 
-        audio_track = [t for t in project.ges_timeline.tracks if isinstance(t, GES.AudioTrack)][0]
+        audio_track = [t for t in project.ges_timeline.get_tracks() if isinstance(t, GES.AudioTrack)][0]
         mainloop = common.create_main_loop()
 
         def progress_cb(project, progress, estimated_time):
@@ -612,7 +572,7 @@ class TestProjectSettings(common.TestCase):
         ccaps = audio_track.props.restriction_caps
         self.assertTrue(ccaps.is_equal_fixed(expected), "%s != %s" % (ccaps, expected))
 
-    def testInitialization(self):
+    def test_initialization(self):
         mainloop = common.create_main_loop()
         uris = collections.deque([
             common.get_sample_uri("flat_colour1_640x480.png"),
@@ -620,12 +580,12 @@ class TestProjectSettings(common.TestCase):
             common.get_sample_uri("1sec_simpsons_trailer.mp4")])
 
         def loaded_cb(project, timeline):
-            project.addUris([uris.popleft()])
+            project.add_uris([uris.popleft()])
 
         def progress_cb(project, progress, estimated_time):
             if progress == 100:
                 if uris:
-                    project.addUris([uris.popleft()])
+                    project.add_uris([uris.popleft()])
                 else:
                     mainloop.quit()
 
@@ -654,11 +614,55 @@ class TestProjectSettings(common.TestCase):
         self.assertEqual(400, project.videoheight)
         self.assertEqual(Gst.Fraction(24, 1), project.videorate)
 
-    def testLoad(self):
+    def test_load(self):
         project = Project(uri="fake.xges", app=common.create_pitivi_mock())
+        self.assertEqual(project.name, "fake")
         self.assertFalse(project._has_default_video_settings)
         self.assertFalse(project._has_default_audio_settings)
 
+    def test_name(self):
+        project = Project(common.create_pitivi_mock())
+
+        project.uri = "file:///tmp/A%20B.xges"
+        self.assertEqual(project.name, "A B")
+
+        project.uri = "file:///tmp/%40%23%24%5E%26%60.xges"
+        self.assertEqual(project.name, "@#$^&`")
+
+    def test_scaled_proxy_size(self):
+        app = common.create_pitivi_mock(default_scaled_proxy_width=123,
+                                        default_scaled_proxy_height=456)
+        manager = ProjectManager(app)
+        project = manager.new_blank_project()
+        self.assertFalse(project.has_scaled_proxy_size())
+        self.assertEqual(project.scaled_proxy_width, 123)
+        self.assertEqual(project.scaled_proxy_height, 456)
+
+        with tempfile.NamedTemporaryFile() as temp_file:
+            uri = Gst.filename_to_uri(temp_file.name)
+            manager.save_project(uri=uri, backup=False)
+            app2 = common.create_pitivi_mock(default_scaled_proxy_width=12,
+                                             default_scaled_proxy_height=45)
+            project2 = ProjectManager(app2).load_project(uri)
+            self.assertFalse(project2.has_scaled_proxy_size())
+            self.assertEqual(project2.scaled_proxy_width, 12)
+            self.assertEqual(project2.scaled_proxy_height, 45)
+
+        project.scaled_proxy_width = 123
+        project.scaled_proxy_height = 456
+        self.assertTrue(project.has_scaled_proxy_size())
+        self.assertEqual(project.scaled_proxy_width, 123)
+        self.assertEqual(project.scaled_proxy_height, 456)
+
+        with tempfile.NamedTemporaryFile() as temp_file:
+            manager.save_project(uri=uri, backup=False)
+            app2 = common.create_pitivi_mock(default_scaled_proxy_width=1,
+                                             default_scaled_proxy_height=4)
+            project2 = ProjectManager(app2).load_project(uri)
+            self.assertTrue(project2.has_scaled_proxy_size())
+            self.assertEqual(project2.scaled_proxy_width, 123)
+            self.assertEqual(project2.scaled_proxy_height, 456)
+
 
 class TestExportSettings(common.TestCase):
 
@@ -707,7 +711,7 @@ class TestExportSettings(common.TestCase):
         mainloop = common.create_main_loop()
 
         def loaded_cb(project, timeline):
-            project.addUris([common.get_sample_uri("tears_of_steel.webm")])
+            project.add_uris([common.get_sample_uri("tears_of_steel.webm")])
 
         def progress_cb(project, progress, estimated_time):
             if progress == 100:
@@ -735,3 +739,21 @@ class TestExportSettings(common.TestCase):
         project.set_rendering(False)
         self.assertEqual(project.videowidth, 960)
         self.assertEqual(project.videoheight, 400)
+
+    def test_set_safe_area_sizes(self):
+        """Checks to ensure that the safe areas values are set correctly."""
+        project = common.create_project()
+        title_horizontal_factor = 0.8
+        title_vertical_factor = 0.9
+        action_horizontal_factor = 0.6
+        action_vertical_factor = 0.7
+
+        project.set_safe_areas_sizes(title_horizontal_factor,
+                                     title_vertical_factor,
+                                     action_horizontal_factor,
+                                     action_vertical_factor)
+
+        self.assertEqual(project.title_safe_area_horizontal, title_horizontal_factor)
+        self.assertEqual(project.title_safe_area_vertical, title_vertical_factor)
+        self.assertEqual(project.action_safe_area_horizontal, action_horizontal_factor)
+        self.assertEqual(project.action_safe_area_vertical, action_vertical_factor)
