@@ -13,25 +13,26 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
 """Tests for the timeline.elements module."""
-# pylint: disable=protected-access,no-self-use,too-many-locals
+# pylint: disable=protected-access,no-self-use
 from unittest import mock
 
 from gi.overrides import GObject
 from gi.repository import Gdk
 from gi.repository import GES
+from gi.repository import Gst
+from gi.repository import Gtk
 from matplotlib.backend_bases import MouseEvent
 
 from pitivi.timeline.elements import GES_TYPE_UI_TYPE
 from pitivi.undo.undo import UndoableActionLog
-from tests.test_timeline_timeline import BaseTestTimeline
+from pitivi.utils.timeline import Zoomable
+from pitivi.utils.ui import LAYER_HEIGHT
 from tests import common
 
 
-class TestKeyframeCurve(BaseTestTimeline):
+class TestKeyframeCurve(common.TestCase):
     """Tests for the KeyframeCurve class."""
 
     def test_keyframe_toggle(self):
@@ -40,14 +41,15 @@ class TestKeyframeCurve(BaseTestTimeline):
         timeline_container.app.action_log = UndoableActionLog()
         timeline = timeline_container.timeline
         ges_layer = timeline.ges_timeline.append_layer()
-        ges_clip1 = self.add_clip(ges_layer, 0)
-        ges_clip2 = self.add_clip(ges_layer, 10)
-        ges_clip3 = self.add_clip(ges_layer, 20, inpoint=100)
+        ges_clip1 = self.add_clip(ges_layer, 0, duration=Gst.SECOND)
+        ges_clip2 = self.add_clip(ges_layer, Gst.SECOND, duration=Gst.SECOND)
+        ges_clip3 = self.add_clip(ges_layer, 2 * Gst.SECOND, inpoint=Gst.SECOND, duration=Gst.SECOND)
+
         # For variety, add TitleClip to the list of clips.
         ges_clip4 = common.create_test_clip(GES.TitleClip)
-        ges_clip4.props.start = 30
-        ges_clip4.props.duration = 4.5
-        ges_layer.add_clip(ges_clip4)
+        ges_clip4.props.start = 3 * Gst.SECOND
+        ges_clip4.props.duration = Gst.SECOND
+        self.assertTrue(ges_layer.add_clip(ges_clip4))
 
         self.check_keyframe_toggle(ges_clip1, timeline_container)
         self.check_keyframe_toggle(ges_clip2, timeline_container)
@@ -70,10 +72,7 @@ class TestKeyframeCurve(BaseTestTimeline):
         offsets = (1, int(duration / 2), int(duration) - 1)
         timeline.selection.select([ges_clip])
 
-        ges_video_source = None
-        for child in ges_clip.get_children(recursive=False):
-            if isinstance(child, GES.VideoSource):
-                ges_video_source = child
+        ges_video_source = ges_clip.find_track_element(None, GES.VideoSource)
         binding = ges_video_source.get_control_binding("alpha")
         control_source = binding.props.control_source
 
@@ -83,7 +82,7 @@ class TestKeyframeCurve(BaseTestTimeline):
         # Add keyframes.
         for offset in offsets:
             position = start + offset
-            pipeline.getPosition = mock.Mock(return_value=position)
+            pipeline.get_position = mock.Mock(return_value=position)
             timeline_container._keyframe_cb(None, None)
             values = [item.timestamp for item in control_source.get_all()]
             self.assertIn(inpoint + offset, values)
@@ -91,7 +90,7 @@ class TestKeyframeCurve(BaseTestTimeline):
         # Remove keyframes.
         for offset in offsets:
             position = start + offset
-            pipeline.getPosition = mock.Mock(return_value=position)
+            pipeline.get_position = mock.Mock(return_value=position)
             timeline_container._keyframe_cb(None, None)
             values = [item.timestamp for item in control_source.get_all()]
             self.assertNotIn(inpoint + offset, values, offset)
@@ -100,7 +99,7 @@ class TestKeyframeCurve(BaseTestTimeline):
         # cannot be toggled.
         for offset in [0, duration]:
             position = start + offset
-            pipeline.getPosition = mock.Mock(return_value=position)
+            pipeline.get_position = mock.Mock(return_value=position)
             values = [item.timestamp for item in control_source.get_all()]
             self.assertIn(inpoint + offset, values)
             timeline_container._keyframe_cb(None, None)
@@ -111,19 +110,21 @@ class TestKeyframeCurve(BaseTestTimeline):
         for offset in [-1, duration + 1]:
             position = min(max(0, start + offset),
                            timeline.ges_timeline.props.duration)
-            pipeline.getPosition = mock.Mock(return_value=position)
+            pipeline.get_position = mock.Mock(return_value=position)
             timeline_container._keyframe_cb(None, None)
             values = [item.timestamp for item in control_source.get_all()]
             self.assertEqual(values, [inpoint, inpoint + duration])
 
-    # pylint: disable=too-many-statements
     def check_keyframe_ui_toggle(self, ges_clip, timeline_container):
         """Checks keyframes toggling by click events."""
         timeline = timeline_container.timeline
 
+        start = ges_clip.props.start
+        start_px = Zoomable.ns_to_pixel(start)
         inpoint = ges_clip.props.in_point
         duration = ges_clip.props.duration
-        offsets = (1, int(duration / 2), int(duration) - 1)
+        duration_px = Zoomable.ns_to_pixel(duration)
+        offsets_px = (1, int(duration_px / 2), int(duration_px) - 1)
         timeline.selection.select([ges_clip])
 
         ges_video_source = ges_clip.find_track_element(None, GES.VideoSource)
@@ -134,8 +135,9 @@ class TestKeyframeCurve(BaseTestTimeline):
         values = [item.timestamp for item in control_source.get_all()]
         self.assertEqual(values, [inpoint, inpoint + duration])
 
-        # Add keyframes.
-        for offset in offsets:
+        # Add keyframes by simulating mouse clicks.
+        for offset_px in offsets_px:
+            offset = Zoomable.pixel_to_ns(start_px + offset_px) - start
             xdata, ydata = inpoint + offset, 1
             x, y = keyframe_curve._ax.transData.transform((xdata, ydata))
 
@@ -146,17 +148,24 @@ class TestKeyframeCurve(BaseTestTimeline):
                 y=y,
                 button=1
             )
-            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
-            keyframe_curve._mpl_button_press_event_cb(event)
-            event.name = "button_release_event"
-            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
-            keyframe_curve._mpl_button_release_event_cb(event)
+            keyframe_curve.translate_coordinates = \
+                mock.Mock(return_value=(start_px + offset_px, None))
+
+            with mock.patch.object(Gtk, "get_event_widget") as get_event_widget:
+                get_event_widget.return_value = keyframe_curve
+                event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
+                keyframe_curve._mpl_button_press_event_cb(event)
+
+                event.name = "button_release_event"
+                event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
+                keyframe_curve._mpl_button_release_event_cb(event)
 
             values = [item.timestamp for item in control_source.get_all()]
             self.assertIn(inpoint + offset, values)
 
-        # Remove keyframes.
-        for offset in offsets:
+        # Remove keyframes by simulating mouse double-clicks.
+        for offset_px in offsets_px:
+            offset = Zoomable.pixel_to_ns(start_px + offset_px) - start
             xdata, ydata = inpoint + offset, 1
             x, y = keyframe_curve._ax.transData.transform((xdata, ydata))
 
@@ -167,19 +176,27 @@ class TestKeyframeCurve(BaseTestTimeline):
                 y=y,
                 button=1
             )
-            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
-            keyframe_curve._mpl_button_press_event_cb(event)
-            event.name = "button_release_event"
-            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
-            keyframe_curve._mpl_button_release_event_cb(event)
-            event.name = "button_press_event"
-            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
-            keyframe_curve._mpl_button_press_event_cb(event)
-            event.guiEvent = Gdk.Event.new(Gdk.EventType._2BUTTON_PRESS)
-            keyframe_curve._mpl_button_press_event_cb(event)
-            event.name = "button_release_event"
-            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
-            keyframe_curve._mpl_button_release_event_cb(event)
+            keyframe_curve.translate_coordinates = \
+                mock.Mock(return_value=(start_px + offset_px, None))
+            with mock.patch.object(Gtk, "get_event_widget") as get_event_widget:
+                get_event_widget.return_value = keyframe_curve
+                event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
+                keyframe_curve._mpl_button_press_event_cb(event)
+
+                event.name = "button_release_event"
+                event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
+                keyframe_curve._mpl_button_release_event_cb(event)
+
+                event.name = "button_press_event"
+                event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
+                keyframe_curve._mpl_button_press_event_cb(event)
+
+                event.guiEvent = Gdk.Event.new(Gdk.EventType._2BUTTON_PRESS)
+                keyframe_curve._mpl_button_press_event_cb(event)
+
+                event.name = "button_release_event"
+                event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
+                keyframe_curve._mpl_button_release_event_cb(event)
 
             values = [item.timestamp for item in control_source.get_all()]
             self.assertNotIn(inpoint + offset, values)
@@ -190,8 +207,49 @@ class TestKeyframeCurve(BaseTestTimeline):
         # Make sure this does not raise any exception
         timeline_container._keyframe_cb(None, None)
 
+    def test_clip_deselect(self):
+        timeline_container = common.create_timeline_container()
+        timeline = timeline_container.timeline
+        ges_layer = timeline.ges_timeline.append_layer()
+        ges_clip1 = self.add_clip(ges_layer, 0, duration=Gst.SECOND)
+        ges_clip2 = self.add_clip(ges_layer, Gst.SECOND, duration=Gst.SECOND)
 
-class TestVideoSource(BaseTestTimeline):
+        # Select clip1 to show its keyframes widget.
+        timeline.selection.select([ges_clip1])
+        # Select both clips. Now clip1 still has the keyframes visible.
+        timeline.selection.select([ges_clip1, ges_clip2])
+
+        ges_video_source = ges_clip1.find_track_element(None, GES.VideoSource)
+        binding = ges_video_source.get_control_binding("alpha")
+        control_source = binding.props.control_source
+        keyframe_curve = ges_video_source.ui.keyframe_curve
+
+        # Simulate a mouse click.
+        xdata, ydata = 1, LAYER_HEIGHT // 2
+        x, y = keyframe_curve._ax.transData.transform((xdata, ydata))
+
+        event = MouseEvent(
+            name="button_press_event",
+            canvas=keyframe_curve,
+            x=x,
+            y=y,
+            button=1
+        )
+        keyframe_curve.translate_coordinates = mock.Mock(return_value=(1, None))
+
+        with mock.patch.object(Gtk, "get_event_widget") as get_event_widget:
+            get_event_widget.return_value = keyframe_curve
+            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_PRESS)
+            keyframe_curve._mpl_button_press_event_cb(event)
+
+            event.name = "button_release_event"
+            event.guiEvent = Gdk.Event.new(Gdk.EventType.BUTTON_RELEASE)
+            keyframe_curve._mpl_button_release_event_cb(event)
+
+        self.assertListEqual([item.timestamp for item in control_source.get_all()], [0, 1000000000])
+
+
+class TestVideoSource(common.TestCase):
     """Tests for the VideoSource class."""
 
     def test_video_source_scaling(self):
@@ -200,7 +258,7 @@ class TestVideoSource(BaseTestTimeline):
         timeline = timeline_container.timeline
         project = timeline.app.project_manager.current_project
 
-        clip = self.addClipsSimple(timeline, 1)[0]
+        clip = self.add_clips_simple(timeline, 1)[0]
 
         video_source = clip.find_track_element(None, GES.VideoUriSource)
         sinfo = video_source.get_asset().get_stream_info()
@@ -214,48 +272,23 @@ class TestVideoSource(BaseTestTimeline):
         self.assertEqual(project.videowidth, width)
         self.assertEqual(project.videoheight, height)
 
-        project.videowidth = sinfo.get_width() * 2
-        project.videoheight = sinfo.get_height() * 2
+        project.set_video_properties(sinfo.get_width() * 2, sinfo.get_height() * 2, project.videorate)
         width = video_source.get_child_property("width")[1]
         height = video_source.get_child_property("height")[1]
         self.assertEqual(project.videowidth, width)
         self.assertEqual(project.videoheight, height)
 
-        project.videowidth = 150
-        project.videoheight = 200
-        width = video_source.get_child_property("width")[1]
-        height = video_source.get_child_property("height")[1]
-
-        expected_width = project.videowidth
-        expected_height = int(sinfo.get_height() * (project.videowidth / sinfo.get_width()))
-        self.assertEqual(width, expected_width)
-        self.assertEqual(height, expected_height)
-
-        video_source.set_child_property("posx", 50)
-        width = video_source.get_child_property("width")[1]
-        height = video_source.get_child_property("height")[1]
-        self.assertEqual(width, expected_width)
-        self.assertEqual(height, expected_height)
-
-        project.videowidth = 1920
-        project.videoheight = 1080
-        self.assertEqual(width, expected_width)
-        self.assertEqual(height, expected_height)
-
-        expected_default_position = {
-            "width": 1920,
-            "height": 800,
-            "posx": 0,
-            "posy": 140}
-        self.assertEqual(video_source.ui.default_position,
-                         expected_default_position)
+        # GES won't ever break aspect ratio, neither should we!
+        project.set_video_properties(150, 200, project.videorate)
+        self.assertEqual(video_source.get_child_property("width").value, width)
+        self.assertEqual(video_source.get_child_property("height").value, height)
 
     def test_rotation(self):
         """Checks the size of the clips flipped 90 degrees."""
         timeline_container = common.create_timeline_container()
         timeline = timeline_container.timeline
 
-        clip = self.addClipsSimple(timeline, 1)[0]
+        clip = self.add_clips_simple(timeline, 1)[0]
 
         video_source = clip.find_track_element(None, GES.VideoUriSource)
         sinfo = video_source.get_asset().get_stream_info()
@@ -295,6 +328,76 @@ class TestVideoSource(BaseTestTimeline):
         self.assertEqual(width, 960)
         self.assertEqual(height, 400)
 
+    @common.setup_project_with_clips
+    @common.setup_clipproperties
+    def test_change_set_project_size(self):
+        """Checks the size of the scaled clips after project settings changes."""
+        clip, = self.layer.get_clips()
+
+        def assert_child_props(clip, expectations):
+            # ellipsize position in expectation means 0
+            for prop in ['posx', 'posy']:
+                if prop not in expectations:
+                    expectations[prop] = 0
+            res = {}
+            for propname in expectations.keys():
+                res[propname] = clip.get_child_property(propname).value
+            self.assertEqual(res, expectations)
+
+        source = clip.find_track_element(None, GES.VideoUriSource)
+        sinfo = source.get_asset().get_stream_info()
+        # Check that the clip has its natural size
+        assert_child_props(clip, {"width": sinfo.get_width(), "height": sinfo.get_height()})
+
+        reset_clip_properties_button = self.transformation_box.builder.get_object("clear_button")
+
+        def check_set_pos_and_project_size(new_position, new_project_width,
+                                           new_project_height, expected_position):
+            self.timeline_container.timeline.selection.select([clip])
+            self.transformation_box.set_source(source)
+            reset_clip_properties_button.clicked()
+
+            assert_child_props(source, {"width": self.project.videowidth, "height": self.project.videoheight})
+
+            for propname, value in new_position.items():
+                source.set_child_property(propname, value)
+            self.project.set_video_properties(new_project_width, new_project_height, self.project.videorate)
+            assert_child_props(source, expected_position)
+
+        # Rescale to half the size
+        check_set_pos_and_project_size(
+            {},
+            sinfo.get_width() / 2,
+            sinfo.get_height() / 2,
+            {"width": sinfo.get_width() / 2, "height": sinfo.get_height() / 2}
+        )
+
+        # Back to natural size
+        check_set_pos_and_project_size(
+            {},
+            sinfo.get_width(),
+            sinfo.get_height(),
+            {"width": sinfo.get_width(), "height": sinfo.get_height()}
+        )
+
+        # Put the video in the bottom left at its half size and rescale project
+        # to half, meaning video should be 1/4th of its size now
+        check_set_pos_and_project_size(
+            {
+                "width": sinfo.get_width() / 2,
+                "height": sinfo.get_height() / 2,
+                "posx": sinfo.get_width() / 2,
+                "posy": sinfo.get_height() / 2,
+            },
+            sinfo.get_width() / 2, sinfo.get_height() / 2,
+            {
+                "width": sinfo.get_width() / 4,
+                "height": sinfo.get_height() / 4,
+                "posx": sinfo.get_width() / 4,
+                "posy": sinfo.get_height() / 4,
+            },
+        )
+
 
 class TestClip(common.TestCase):
     """Tests for the Clip class."""
