@@ -13,12 +13,13 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
+"""Tests for the pitivi.undo.undo module."""
+# pylint: disable=protected-access
 from unittest import mock
 
 from gi.repository import GES
+from gi.repository import Gst
 
 from pitivi.undo.undo import GObjectObserver
 from pitivi.undo.undo import PropertyChangedAction
@@ -31,11 +32,10 @@ from tests import common
 
 
 class TestUndoableActionStack(common.TestCase):
+    """Tests for the UndoableActionStack class."""
 
-    def testUndoDo(self):
-        """
-        Test an undo() do() sequence.
-        """
+    def test_undo_do(self):
+        """Checks an undo() and do() sequence."""
         state = {"actions": 2}
 
         class Action(UndoableAction):
@@ -58,10 +58,8 @@ class TestUndoableActionStack(common.TestCase):
         stack.do()
         self.assertEqual(state["actions"], 2)
 
-    def testUndoError(self):
-        """
-        Undo a stack containing a failing action.
-        """
+    def test_undo_error(self):
+        """Checks undo a stack containing a failing action."""
         stack = UndoableActionStack("meh")
         action1 = mock.Mock(spec=UndoableAction)
         action1.expand.return_value = False
@@ -80,44 +78,49 @@ class TestUndoableActionStack(common.TestCase):
 
 
 class TestUndoableActionLog(common.TestCase):
+    """Tests for the UndoableActionLog class."""
 
     def setUp(self):
         self.log = UndoableActionLog()
-        self._connectToUndoableActionLog(self.log)
+        self._connect_to_undoable_action_log(self.log)
         self.signals = []
 
     def tearDown(self):
-        self._disconnectFromUndoableActionLog(self.log)
+        self._disconnect_from_undoable_action_log()
 
-    def _undoActionLogSignalCb(self, log, *args):
+    def check_signals(self, *expected_signals):
+        signals = [item[0] for item in self.signals]
+        self.assertListEqual(signals, list(expected_signals))
+
+    def _undo_action_log_signal_cb(self, log, *args):
         args = list(args)
-        signalName = args.pop(-1)
-        self.signals.append((signalName, args))
+        signal_name = args.pop(-1)
+        self.signals.append((signal_name, args))
 
-    def _connectToUndoableActionLog(self, log):
-        for signalName in ("begin", "push", "rollback", "commit", "move"):
-            log.connect(signalName, self._undoActionLogSignalCb, signalName)
+    def _connect_to_undoable_action_log(self, log):
+        for signal_name in ("begin", "push", "rollback", "commit", "move"):
+            log.connect(signal_name, self._undo_action_log_signal_cb, signal_name)
 
-    def _disconnectFromUndoableActionLog(self, log):
-        self.log.disconnect_by_func(self._undoActionLogSignalCb)
+    def _disconnect_from_undoable_action_log(self):
+        self.log.disconnect_by_func(self._undo_action_log_signal_cb)
 
-    def testRollbackWrongState(self):
+    def test_rollback_wrong_state(self):
         self.assertRaises(UndoWrongStateError, self.log.rollback)
 
-    def testCommitWrongState(self):
+    def test_commit_wrong_state(self):
         self.assertRaises(UndoWrongStateError, self.log.commit, "")
 
-    def testPushWrongState(self):
+    def test_push_wrong_state(self):
         # no error in this case
         self.log.push(None)
 
-    def testUndoWrongState(self):
+    def test_undo_wrong_state(self):
         self.assertRaises(UndoWrongStateError, self.log.undo)
 
-    def testRedoWrongState(self):
+    def test_redo_wrong_state(self):
         self.assertRaises(UndoWrongStateError, self.log.redo)
 
-    def testCheckpoint(self):
+    def test_checkpoint(self):
         self.log.begin("meh")
         self.log.push(mock.Mock(spec=UndoableAction))
         self.assertRaises(UndoWrongStateError, self.log.checkpoint)
@@ -125,7 +128,7 @@ class TestUndoableActionLog(common.TestCase):
         self.log.checkpoint()
         self.assertNotEqual(self.log._checkpoint, None)
 
-    def testDirty(self):
+    def test_dirty(self):
         self.assertFalse(self.log.dirty())
         self.log.begin("meh")
         self.log.push(mock.Mock(spec=UndoableAction))
@@ -138,15 +141,13 @@ class TestUndoableActionLog(common.TestCase):
         self.log.redo()
         self.assertFalse(self.log.dirty())
 
-    def testCommit(self):
-        """
-        Commit a stack.
-        """
+    def test_commit(self):
+        """Checks committing a stack."""
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
         self.assertEqual(len(self.signals), 1)
-        name, (stack,) = self.signals[0]
+        name, (_stack,) = self.signals[0]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
@@ -154,9 +155,9 @@ class TestUndoableActionLog(common.TestCase):
         self.log.push(mock.Mock(spec=UndoableAction))
         self.log.commit("meh")
         self.assertEqual(len(self.signals), 3)
-        name, (stack, action) = self.signals[1]
+        name, (_stack, _action) = self.signals[1]
         self.assertEqual(name, "push")
-        name, (stack,) = self.signals[2]
+        name, (_stack,) = self.signals[2]
         self.assertEqual(name, "commit")
         self.assertFalse(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 1)
@@ -166,15 +167,13 @@ class TestUndoableActionLog(common.TestCase):
         self.log.begin("meh")
         self.assertRaises(UndoWrongStateError, self.log.commit, "notmeh")
 
-    def testNestedCommit(self):
-        """
-        Do two nested commits.
-        """
+    def test_nested_commit(self):
+        """Checks two nested commits."""
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
         self.assertEqual(len(self.signals), 1)
-        name, (stack,) = self.signals[0]
+        name, (_stack,) = self.signals[0]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
@@ -182,7 +181,7 @@ class TestUndoableActionLog(common.TestCase):
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("nested")
         self.assertEqual(len(self.signals), 2)
-        name, (stack,) = self.signals[1]
+        name, (_stack,) = self.signals[1]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
@@ -190,9 +189,9 @@ class TestUndoableActionLog(common.TestCase):
         self.log.push(mock.Mock(spec=UndoableAction))
         self.log.commit("nested")
         self.assertEqual(len(self.signals), 4)
-        name, (stack, action) = self.signals[2]
+        name, (_stack, _action) = self.signals[2]
         self.assertEqual(name, "push")
-        name, (stack,) = self.signals[3]
+        name, (_stack,) = self.signals[3]
         self.assertEqual(name, "commit")
         self.assertTrue(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 0)
@@ -201,7 +200,7 @@ class TestUndoableActionLog(common.TestCase):
         self.assertEqual(self.log.undo_stacks, [])
         self.log.commit("meh")
         self.assertEqual(len(self.signals), 5)
-        name, (stack,) = self.signals[4]
+        name, (_stack,) = self.signals[4]
         self.assertEqual(name, "commit")
         self.assertFalse(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 1)
@@ -218,35 +217,47 @@ class TestUndoableActionLog(common.TestCase):
         # For now, we call the finalizing action only for the top stack.
         action2.do.assert_not_called()
 
-    def testRollback(self):
-        """
-        Test a rollback.
-        """
+    def test_rollback(self):
+        """Checks a rollback."""
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
-        self.assertEqual(len(self.signals), 1)
-        name, (stack,) = self.signals[0]
+        self.check_signals("begin")
+        name, (_stack,) = self.signals[0]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
+        action = mock.Mock(spec=UndoableAction)
+        self.log.push(action)
+
         self.log.rollback()
-        self.assertEqual(len(self.signals), 2)
-        name, (stack,) = self.signals[1]
+
+        action.undo.assert_called_once_with()
+
+        self.check_signals("begin", "push", "rollback")
+        name, (_stack,) = self.signals[2]
         self.assertEqual(name, "rollback")
         self.assertFalse(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
 
-    def testNestedRollback(self):
-        """
-        Test two nested rollbacks.
-        """
+    def test_rollback_noop(self):
+        """Checks a rollback which does not act."""
+        self.log.begin("meh")
+
+        action = mock.Mock(spec=UndoableAction)
+        self.log.push(action)
+
+        self.log.rollback(undo=False)
+        action.undo.assert_not_called()
+
+    def test_nested_rollback(self):
+        """Checks two nested rollbacks."""
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
         self.assertEqual(len(self.signals), 1)
-        name, (stack,) = self.signals[0]
+        name, (_stack,) = self.signals[0]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
@@ -254,13 +265,13 @@ class TestUndoableActionLog(common.TestCase):
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("nested")
         self.assertEqual(len(self.signals), 2)
-        name, (stack,) = self.signals[1]
+        name, (_stack,) = self.signals[1]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
         self.log.rollback()
         self.assertEqual(len(self.signals), 3)
-        name, (stack,) = self.signals[2]
+        name, (_stack,) = self.signals[2]
         self.assertEqual(name, "rollback")
         self.assertTrue(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 0)
@@ -268,20 +279,18 @@ class TestUndoableActionLog(common.TestCase):
 
         self.log.rollback()
         self.assertEqual(len(self.signals), 4)
-        name, (stack,) = self.signals[3]
+        name, (_stack,) = self.signals[3]
         self.assertEqual(name, "rollback")
         self.assertFalse(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
 
-    def testUndoRedo(self):
-        """
-        Try an undo() redo() sequence.
-        """
+    def test_undo_redo(self):
+        """Tries an undo() redo() sequence."""
         # begin
         self.log.begin("meh")
         self.assertEqual(len(self.signals), 1)
-        name, (stack,) = self.signals[0]
+        name, (_stack,) = self.signals[0]
         self.assertEqual(name, "begin")
         self.assertTrue(self.log.is_in_transaction())
 
@@ -290,23 +299,23 @@ class TestUndoableActionLog(common.TestCase):
         action1.expand.return_value = False
         self.log.push(action1)
         self.assertEqual(len(self.signals), 2)
-        name, (stack, signalAction) = self.signals[1]
+        name, (_stack, signal_action) = self.signals[1]
         self.assertEqual(name, "push")
-        self.assertTrue(action1 is signalAction)
+        self.assertTrue(action1 is signal_action)
 
         action2 = mock.Mock(spec=UndoableAction)
         self.log.push(action2)
         self.assertEqual(len(self.signals), 3)
-        name, (stack, signalAction) = self.signals[2]
+        name, (_stack, signal_action) = self.signals[2]
         self.assertEqual(name, "push")
-        self.assertTrue(action2 is signalAction)
+        self.assertTrue(action2 is signal_action)
 
         # commit
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.commit("meh")
         self.assertEqual(len(self.signals), 4)
-        name, (stack,) = self.signals[3]
+        name, (_stack,) = self.signals[3]
         self.assertEqual(name, "commit")
         self.assertFalse(self.log.is_in_transaction())
         self.assertEqual(len(self.log.undo_stacks), 1)
@@ -319,7 +328,7 @@ class TestUndoableActionLog(common.TestCase):
         # undo what we just committed
         self.log.undo()
         self.assertEqual(len(self.signals), 5)
-        name, stack = self.signals[4]
+        name, _args = self.signals[4]
         self.assertEqual(name, "move")
         self.assertEqual(len(self.log.undo_stacks), 0)
         self.assertEqual(len(self.log.redo_stacks), 1)
@@ -331,7 +340,7 @@ class TestUndoableActionLog(common.TestCase):
         # redo
         self.log.redo()
         self.assertEqual(len(self.signals), 6)
-        name, stack = self.signals[5]
+        name, _args = self.signals[5]
         self.assertEqual(name, "move")
         self.assertEqual(len(self.log.undo_stacks), 1)
         self.assertEqual(len(self.log.redo_stacks), 0)
@@ -340,10 +349,8 @@ class TestUndoableActionLog(common.TestCase):
         self.assertEqual(action2.do.call_count, 1)
         self.assertEqual(action2.undo.call_count, 1)
 
-    def testOrder(self):
-        """
-        Test that actions are undone and redone in the correct order.
-        """
+    def test_order(self):
+        """Checks actions are undone and redone in the correct order."""
         order = mock.Mock()
         order.action1 = mock.Mock(spec=UndoableAction)
         order.action1.expand.return_value = False
@@ -408,12 +415,42 @@ class TestUndoableActionLog(common.TestCase):
         self.assertEqual(len(self.log.redo_stacks), 0)
 
 
+class TestRollback(common.TestCase):
+
+    @common.setup_timeline
+    def test_rollback_of_nested_operation_does_not_add_actions_to_parent(self):
+        clip1 = GES.TitleClip()
+        clip1.set_start(0 * Gst.SECOND)
+        clip1.set_duration(1 * Gst.SECOND)
+
+        clip2 = GES.TitleClip()
+        clip2.set_start(1 * Gst.SECOND)
+        clip2.set_duration(1 * Gst.SECOND)
+
+        # begin parent operation
+        self.action_log.begin("parent")
+
+        # push one parent action
+        self.layer.add_clip(clip1)
+        stack_snapshot = self.action_log._get_last_stack().done_actions[::]
+
+        # begin nested operation
+        self.action_log.begin("nested")
+
+        # push one nested action
+        self.layer.add_clip(clip2)
+
+        self.action_log.rollback()
+        self.assertListEqual(self.action_log._get_last_stack().done_actions, stack_snapshot)
+
+
 class TestGObjectObserver(common.TestCase):
+    """Tests for the GObjectObserver class."""
 
     def test_property_change(self):
         action_log = UndoableActionLog()
         action_log.begin("complex stuff")
-        stack, = action_log.stacks
+        stack = action_log.stacks[0]
 
         clip = GES.TitleClip()
         clip.props.start = 1
