@@ -13,9 +13,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
 from gi.repository import GES
 from gi.repository import Gtk
 
@@ -28,12 +26,10 @@ class TestProjectUndo(common.TestCase):
     def setUp(self):
         super(TestProjectUndo, self).setUp()
         self.app = common.create_pitivi()
-        self.assertTrue(self.app.project_manager.newBlankProject())
-
-        self.project = self.app.project_manager.current_project
+        self.project = self.app.project_manager.new_blank_project()
         self.action_log = self.app.action_log
 
-    def test_new_project_has_nothing_to_undo(self):
+    def test_new_project_nothing_to_undo(self):
         mainloop = common.create_main_loop()
 
         def loaded_cb(project, timeline):
@@ -51,7 +47,7 @@ class TestProjectUndo(common.TestCase):
         mainloop = common.create_main_loop()
 
         def loaded_cb(unused_project, unused_timeline):
-            self.project.addUris(uris)
+            self.project.add_uris(uris)
 
         self.project.connect_after("loaded", loaded_cb)
 
@@ -63,10 +59,13 @@ class TestProjectUndo(common.TestCase):
 
         mainloop.run()
 
+        self.assertTrue(self.action_log.has_assets_operations())
         self.assertEqual(len(self.project.list_assets(GES.Extractable)), 1)
         self.action_log.undo()
+        self.assertFalse(self.action_log.has_assets_operations())
         self.assertEqual(len(self.project.list_assets(GES.Extractable)), 0)
         self.action_log.redo()
+        self.assertTrue(self.action_log.has_assets_operations())
         self.assertEqual(len(self.project.list_assets(GES.Extractable)), 1)
 
     def test_use_proxy(self):
@@ -76,7 +75,7 @@ class TestProjectUndo(common.TestCase):
 
         def loaded_cb(unused_project, unused_timeline):
             # The new project has been loaded, add some assets.
-            self.project.addUris(uris)
+            self.project.add_uris(uris)
         self.project.connect_after("loaded", loaded_cb)
 
         def progress_cb(unused_project, progress, unused_estimated_time):
@@ -126,25 +125,22 @@ class TestProjectUndo(common.TestCase):
                                        project=self.project,
                                        app=self.app)
 
-        def assert_meta(title, author, year):
-            self.assertEqual(self.project.name, title)
+        def assert_meta(author, year):
             self.assertEqual(self.project.author, author)
             self.assertEqual(self.project.year, year)
 
-        dialog.title_entry.set_text("t1")
         dialog.author_entry.set_text("a1")
         dialog.year_spinbutton.set_value(2001)
-        dialog.updateProject()
-        assert_meta("t1", "a1", "2001")
+        dialog.update_project()
+        assert_meta("a1", "2001")
 
-        dialog.title_entry.set_text("t2")
         dialog.author_entry.set_text("a2")
         dialog.year_spinbutton.set_value(2002)
-        dialog.updateProject()
-        assert_meta("t2", "a2", "2002")
+        dialog.update_project()
+        assert_meta("a2", "2002")
 
         self.action_log.undo()
-        assert_meta("t1", "a1", "2001")
+        assert_meta("a1", "2001")
 
         self.action_log.redo()
-        assert_meta("t2", "a2", "2002")
+        assert_meta("a2", "2002")
